@@ -385,9 +385,19 @@ sw_size_allocate(GtkWidget *widget, GtkAllocation *alloc, gpointer data)
 	GtkGS *view = GTK_GS(data);
 	guint border = gtk_container_get_border_width(GTK_CONTAINER(widget));
 	gint w, h;
+	gint scrollbar_spacing;
+	GtkRequisition req;
 
-	w = alloc->width - 2*border;
-	h = alloc->height - 2*border;
+	gtk_widget_style_get (widget,
+						  "scrollbar_spacing", &scrollbar_spacing,
+						  NULL);
+	w = alloc->width - 2*border - 2*widget->style->xthickness - 
+		2*scrollbar_spacing;
+	if(NULL != GTK_SCROLLED_WINDOW(widget)->vscrollbar) {
+		gtk_widget_size_request(GTK_SCROLLED_WINDOW(widget)->vscrollbar, &req);
+		w -= req.width;
+	}
+	h = alloc->height - 2*border - 2*widget->style->ythickness;
 	w = MAX(w, 0);
 	h = MAX(h, 0);
 	gtk_gs_set_available_size(view, w, h);
@@ -595,15 +605,12 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		break;
 	case GDK_Page_Up:
 	case GDK_KP_Page_Up:
-		gtk_adjustment_set_value(gs->vadj, gs->vadj->value - gs->vadj->page_increment);
+		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 		break;
 	case GDK_Page_Down:
 	case GDK_KP_Page_Down:
-		val = gs->vadj->value + gs->vadj->page_increment;
-		if (val > gs->vadj->upper - gs->vadj->page_size)
-			val = gs->vadj->upper - gs->vadj->page_size;
-		gtk_adjustment_set_value(gs->vadj, val);
-			break;
+		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
+		break;
 	case GDK_plus:
 		g_signal_emit_by_name(G_OBJECT (control->priv->zoomable),
 							  "zoom_in");
