@@ -666,6 +666,10 @@ static void
 verb_HelpContents(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
 	GError *error = NULL;
+        GgvWindow *win = GGV_WINDOW(data);
+
+        if(win->fullscreen)
+                ggv_window_set_fullscreen(win, FALSE);
 	gnome_help_display ("ggv",NULL,&error);
 }
 
